<template>
  <a-modal :title='title' :width='500' :visible='visible' :maskClosable='false' :confirmLoading='confirmLoading'
           :okButtonProps='{ props: {disabled: disableSubmit} }' @ok='handleOk' @cancel='handleCancel' cancelText='关闭'>
    <a-spin :spinning='confirmLoading'>
      <a-form :form='form'>
        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item label='采集软件' :labelCol='labelCol' :wrapperCol='wrapperCol'>
              <j-upload v-model='fileList' text='上传' :bizPath='serverCode' number='1'
                        v-decorator="[ 'fileList', validatorRules.fileList]" />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter='12'>
          <a-col :span='32'>
            <a-form-item label='采集软件版本号' :labelCol='labelCol' :wrapperCol='wrapperCol'>
              <a-input :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入采集软件版本号' allow-clear
                       :maxLength='10' v-decorator="[ 'latestCollectVersion', validatorRules.latestCollectVersion]" />
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>
    <template slot='footer'>
      <a-button :style="{ marginRight: '8px' }" @click='handleCancel'>关闭</a-button>
      <a-button @click='handleOk' type='primary'>确定</a-button>
    </template>
  </a-modal>
</template>

<script>
import JUpload from '@/components/jeecg/JUpload'
import { httpAction } from '@/api/manage'
import pick from 'lodash.pick'

export default {
  name: 'AuthorizeModel',
  components: {
    JUpload
  },
  data() {
    return {
      serverCode: '',
      fileList: [],
      title: '',
      // file 信息
      uploadValues: {},
      visible: false,
      model: {},
      confirmLoading: false,
      form: this.$form.createForm(this),
      url: {
        edit: '/serve/deploy/edit/collect'
      },
      disableSubmit: false,
      validatorRules: {
        latestCollectVersion: {
          rules: [{
            required: true,
            message: '请输入采集软件版本号'
          },
            {
              min: 0,
              max: 30,
              message: '长度不超过 30 个字符',
              trigger: 'blur'
            }
          ]
        },
        fileList: {
          rules: [{
            required: true,
            message: '请上传采集软件'
          }]
        }
      },
      labelCol: {
        xs: {
          span: 24
        },
        sm: {
          span: 8
        }
      },
      wrapperCol: {
        xs: {
          span: 24
        },
        sm: {
          span: 12
        }
      }
    }
  },

  methods: {
    add() {
      this.edit({})
    },
    edit(record) {
      this.form.resetFields()
      this.model = Object.assign({}, record)
      this.serverCode = this.model.serverCode + '/software'
      this.visible = true
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model, 'authorizeCode', 'bucket', 'organization', 'port', 'address', 'password'))
      })
    },
    close() {
      this.$emit('close')
      this.visible = false
    },
    handleOk() {
      const that = this
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true
          let formData = Object.assign(this.model, values)
          formData.newCollectAddress = this.fileList
          httpAction(this.url.edit, formData, 'put').then((res) => {
            if (res.success) {
              that.$message.success('采集软件更新成功')
              that.$emit('ok', res.result)
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
            that.close()
          })
        }
      })
    },
    handleCancel() {
      this.close()
    }
  }
}
</script>

<style scoped>

</style>
